@@ -1,5 +1,5 @@
 package Object::eBay;
-our $VERSION = '0.4.0';
+our $VERSION = '0.5.1';
 
 use Class::Std; {
     use warnings;
@@ -528,6 +528,10 @@ You can also look for information at:
 
 =over 4
 
+=item * GitHub
+
+L<http://github.com/mndrix/Object-eBay>
+
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Object-eBay>
